@@ -21,10 +21,12 @@
 
 #include <kdebug.h>
 
-#include <QTimer>
+#include <QtCore/QTimer>
 
 using namespace Akonadi;
 
+//@cond PRIVATE
+
 ResourceScheduler::ResourceScheduler( QObject *parent ) :
     QObject( parent ),
     mOnline( false )
@@ -79,6 +81,8 @@ void ResourceScheduler::scheduleChangeReplay()
 
 void ResourceScheduler::taskDone()
 {
+  if ( isEmpty() )
+    emit status( AgentBase::Idle );
   mCurrentTask = Task();
   scheduleNext();
 }
@@ -97,6 +101,9 @@ void ResourceScheduler::scheduleNext()
 
 void ResourceScheduler::executeNext()
 {
+  if( mCurrentTask.type != Invalid || mTaskList.isEmpty() )
+    return;
+
   mCurrentTask = mTaskList.takeFirst();
   switch ( mCurrentTask.type ) {
     case SyncAll:
@@ -138,4 +145,6 @@ void ResourceScheduler::setOnline(bool state)
   }
 }
 
+//@endcond
+
 #include "resourcescheduler.moc"
