@@ -568,8 +568,8 @@ void GDataPrivate::slotListBlogs( Syndication::Loader *loader,
   QList<QMap<QString,QString> > blogsList;
 
   QList<Syndication::ItemPtr> items = feed->items();
-  QList<Syndication::ItemPtr>::ConstIterator it = items.begin();
-  QList<Syndication::ItemPtr>::ConstIterator end = items.end();
+  QList<Syndication::ItemPtr>::ConstIterator it = items.constBegin();
+  QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
     QRegExp rx( "blog-(\\d+)" );
     QMap<QString,QString> blogInfo;
@@ -610,8 +610,8 @@ void GDataPrivate::slotListComments( Syndication::Loader *loader,
   QList<KBlog::BlogComment> commentList;
 
   QList<Syndication::ItemPtr> items = feed->items();
-  QList<Syndication::ItemPtr>::ConstIterator it = items.begin();
-  QList<Syndication::ItemPtr>::ConstIterator end = items.end();
+  QList<Syndication::ItemPtr>::ConstIterator it = items.constBegin();
+  QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
     BlogComment comment;
     QRegExp rx( "post-(\\d+)" );
@@ -656,8 +656,8 @@ void GDataPrivate::slotListAllComments( Syndication::Loader *loader,
   QList<KBlog::BlogComment> commentList;
 
   QList<Syndication::ItemPtr> items = feed->items();
-  QList<Syndication::ItemPtr>::ConstIterator it = items.begin();
-  QList<Syndication::ItemPtr>::ConstIterator end = items.end();
+  QList<Syndication::ItemPtr>::ConstIterator it = items.constBegin();
+  QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
     BlogComment comment;
     QRegExp rx( "post-(\\d+)" );
@@ -708,8 +708,8 @@ void GDataPrivate::slotListRecentPosts( Syndication::Loader *loader,
   QList<KBlog::BlogPost> postList;
 
   QList<Syndication::ItemPtr> items = feed->items();
-  QList<Syndication::ItemPtr>::ConstIterator it = items.begin();
-  QList<Syndication::ItemPtr>::ConstIterator end = items.end();
+  QList<Syndication::ItemPtr>::ConstIterator it = items.constBegin();
+  QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
     BlogPost post;
     QRegExp rx( "post-(\\d+)" );
@@ -761,8 +761,8 @@ void GDataPrivate::slotFetchPost( Syndication::Loader *loader,
     return;
   }
   QList<Syndication::ItemPtr> items = feed->items();
-  QList<Syndication::ItemPtr>::ConstIterator it = items.begin();
-  QList<Syndication::ItemPtr>::ConstIterator end = items.end();
+  QList<Syndication::ItemPtr>::ConstIterator it = items.constBegin();
+  QList<Syndication::ItemPtr>::ConstIterator end = items.constEnd();
   for ( ; it != end; ++it ) {
     QRegExp rx( "post-(\\d+)" );
     if ( rx.indexIn( ( *it )->id() ) != -1 && rx.cap(1) == post->postId() ){
