@@ -24,7 +24,7 @@
   defines the ICalFormat class.
 
   @brief
-  iCalendar format implementation.
+  iCalendar format implementation: a layer of abstraction for libical.
 
   @author Cornelius Schumacher \<schumacher@kde.org\>
 */
@@ -237,7 +237,7 @@ QString ICalFormat::toString( Calendar *cal )
   // todos
   Todo::List todoList = cal->rawTodos();
   Todo::List::ConstIterator it;
-  for ( it = todoList.begin(); it != todoList.end(); ++it ) {
+  for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
     component = d->mImpl->writeTodo( *it, tzlist, &tzUsedList );
     icalcomponent_add_component( calendar, component );
   }
@@ -245,7 +245,7 @@ QString ICalFormat::toString( Calendar *cal )
   // events
   Event::List events = cal->rawEvents();
   Event::List::ConstIterator it2;
-  for ( it2 = events.begin(); it2 != events.end(); ++it2 ) {
+  for ( it2 = events.constBegin(); it2 != events.constEnd(); ++it2 ) {
     if ( *it2 ) {
       component = d->mImpl->writeEvent( *it2, tzlist, &tzUsedList );
       icalcomponent_add_component( calendar, component );
@@ -255,14 +255,15 @@ QString ICalFormat::toString( Calendar *cal )
   // journals
   Journal::List journals = cal->journals();
   Journal::List::ConstIterator it3;
-  for ( it3 = journals.begin(); it3 != journals.end(); ++it3 ) {
+  for ( it3 = journals.constBegin(); it3 != journals.constEnd(); ++it3 ) {
     component = d->mImpl->writeJournal( *it3, tzlist, &tzUsedList );
     icalcomponent_add_component( calendar, component );
   }
 
   // time zones
   const ICalTimeZones::ZoneMap zones = tzUsedList.zones();
-  for ( ICalTimeZones::ZoneMap::ConstIterator it = zones.begin();  it != zones.end();  ++it ) {
+  for ( ICalTimeZones::ZoneMap::ConstIterator it=zones.constBegin();
+        it != zones.constEnd(); ++it ) {
     icaltimezone *tz = (*it).icalTimezone();
     if ( !tz ) {
       kError() << "bad time zone";
@@ -477,8 +478,6 @@ ScheduleMessage *ICalFormat::parseScheduleMessage( Calendar *cal,
     return 0;
   }
 
-  kDebug() << "getting method...";
-
   icalproperty_method icalmethod = icalproperty_get_method( m );
   iTIPMethod method;
 
@@ -513,8 +512,6 @@ ScheduleMessage *ICalFormat::parseScheduleMessage( Calendar *cal,
     break;
   }
 
-  kDebug() << "restriction...";
-
   if ( !icalrestriction_check( message ) ) {
     kWarning() << endl
                << "kcal library reported a problem while parsing:";
@@ -522,7 +519,7 @@ ScheduleMessage *ICalFormat::parseScheduleMessage( Calendar *cal,
                << d->mImpl->extractErrorProperty( c );
   }
 
-  Incidence *existingIncidence = cal->incidenceFromSchedulingID( incidence->uid() );
+  Incidence *existingIncidence = cal->incidence( incidence->uid() );
 
   icalcomponent *calendarComponent = 0;
   if ( existingIncidence ) {
@@ -540,15 +537,14 @@ ScheduleMessage *ICalFormat::parseScheduleMessage( Calendar *cal,
       icalcomponent_add_component( calendarComponent,
                                    d->mImpl->writeEvent( event ) );
     }
+  } else {
+    icalcomponent_free( message );
+    return new ScheduleMessage( incidence, method, ScheduleMessage::Unknown );
   }
 
-  kDebug() << "classify...";
-
   icalproperty_xlicclass result =
     icalclassify( message, calendarComponent, (char *)"" );
 
-  kDebug() << "returning with result = " << result;
-
   ScheduleMessage::Status status;
 
   switch ( result ) {
@@ -573,11 +569,9 @@ ScheduleMessage *ICalFormat::parseScheduleMessage( Calendar *cal,
     break;
   }
 
-  kDebug() << "status =" << status;
-
   icalcomponent_free( message );
-  if ( calendarComponent )
-    icalcomponent_free( calendarComponent );
+  icalcomponent_free( calendarComponent );
+
   return new ScheduleMessage( incidence, method, status );
 }
 
