@@ -156,8 +156,8 @@ void ICalTimeZones::clear()
 ICalTimeZone ICalTimeZones::zone( const QString &name ) const
 {
   if ( !name.isEmpty() ) {
-    ZoneMap::ConstIterator it = d->zones.find( name );
-    if ( it != d->zones.end() ) {
+    ZoneMap::ConstIterator it = d->zones.constFind( name );
+    if ( it != d->zones.constEnd() ) {
       return it.value();
     }
   }
@@ -271,7 +271,8 @@ bool ICalTimeZone::update( const ICalTimeZone &other )
     return false;
   }
 
-  setData( other.data()->clone(), other.source() );
+  KTimeZoneData* otherData = other.data() ? other.data()->clone() : 0;
+  setData( otherData, other.source() );
   return true;
 }
 
@@ -625,8 +626,9 @@ ICalTimeZoneData::~ICalTimeZoneData()
 ICalTimeZoneData &ICalTimeZoneData::operator=( const ICalTimeZoneData &rhs )
 {
   // check for self assignment
-  if ( &rhs == this )
+  if ( &rhs == this ) {
     return *this;
+  }
 
   KTimeZoneData::operator=( rhs );
   d->location = rhs.d->location;
@@ -882,7 +884,7 @@ ICalTimeZone ICalTimeZoneSource::parse( icaltimezone *tz )
    * This is both easier and provides more complete information than
    * extracting already parsed data from icaltimezone.
    */
-  return parse( icaltimezone_get_component( tz ) );
+  return tz ? parse( icaltimezone_get_component( tz ) ) : ICalTimeZone();
 }
 
 //@cond PRIVATE
