@@ -136,7 +136,7 @@ void Todo::setDtDue( const KDateTime &dtDue, bool first )
 
   /*if (mReadOnly) return;
   const Alarm::List& alarms = alarms();
-  for (Alarm* alarm = alarms.first(); alarm; alarm = alarms.next()) {
+  for (Alarm *alarm = alarms.first(); alarm; alarm = alarms.next()) {
     if (alarm->enabled()) {
       alarm->setTime(alarm->time().addSecs(diffsecs));
     }
@@ -157,7 +157,7 @@ void Todo::setDtDue( const KDateTime &dtDue, bool first )
   //kDebug() << "setDtDue says date is" << d->mDtDue.toString();
 
   /*const Alarm::List& alarms = alarms();
-  for (Alarm* alarm = alarms.first(); alarm; alarm = alarms.next())
+  for (Alarm *alarm = alarms.first(); alarm; alarm = alarms.next())
     alarm->setAlarmStart(d->mDtDue);*/
 
   updated();
@@ -478,7 +478,10 @@ bool Todo::recursOn( const QDate &date, const KDateTime::Spec &timeSpec ) const
 
 bool Todo::isOverdue() const
 {
-  if ( !dtDue().isValid() ) return false; // if it's never due, it can't be overdue
+  if ( !dtDue().isValid() ) {
+    return false; // if it's never due, it can't be overdue
+  }
+
   bool inPast = allDay() ?
                 dtDue().date() < QDate::currentDate() :
                 dtDue() < KDateTime::currentUtcDateTime();
